<?

class Gateway
{
    private $address;
    private $gateway_login;
    private $gateway_password;
    private $virtual_pos_id;
    private $agent_id;
    private $payment_type_id;
    private $token;
    private $success_url;
    private $webhook_url;

    public function __construct()
    {
        $this->address = CSalePaySystemAction::GetParamValue("GATEWAY_ADDRESS");
        $this->gateway_login = CSalePaySystemAction::GetParamValue("GATEWAY_LOGIN");
        $this->gateway_password = CSalePaySystemAction::GetParamValue("GATEWAY_PASSWORD");
        $this->virtual_pos_id = intval(CSalePaySystemAction::GetParamValue("VIRTUAL_POS_ID"));
        $this->agent_id = intval(CSalePaySystemAction::GetParamValue("AGENT_ID"));
        $this->payment_type_id = intval(CSalePaySystemAction::GetParamValue("PAYMENT_TYPE_ID"));

        $this->success_url = (CMain::IsHTTPS() ? 'https://' : 'http://') . $_SERVER["HTTP_HOST"] . '/personal/orders';
        $this->webhook_url = (CMain::IsHTTPS() ? 'https://' : 'http://') . $_SERVER["HTTP_HOST"] . '/personal/order/payment/qazaqpay_result.php';
    }

    public function getGatewayAuthToken()
    {
        $body = json_encode(array(
            'login' => $this->gateway_login,
            'password' => $this->gateway_password
        ), true);

        $ctp_url = $this->address . '/api/auth/login';

        $curl = curl_init($ctp_url);
        // curl_setopt($curl, CURLOPT_PORT, 443);
        curl_setopt($curl, CURLOPT_HEADER, 0);
        curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, 0);
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($curl, CURLOPT_HTTPHEADER, array('Content-Type: application/json'));
        curl_setopt($curl, CURLOPT_FORBID_REUSE, 1);
        curl_setopt($curl, CURLOPT_FRESH_CONNECT, 1);
        curl_setopt($curl, CURLOPT_POST, 1);
        curl_setopt($curl, CURLOPT_POSTFIELDS, $body);

        $response = curl_exec($curl);
        $curl_error = curl_error($curl);
        $curl_errno = curl_errno($curl);
        curl_close($curl);

        if (!$response) {
            return;
        }

        $data = json_decode($response, true);

        if (!isset($data["token"])) {
            return;
        }

        $this->token = $data["token"];
    }

    public function initPayment($order_id, $fullname, $amount) {
        $body = array(
            "virtual_pos_id" => $this->virtual_pos_id,
            "agent_id" => $this->agent_id,
            "success_url" => $this->success_url,
            "error_url" => $this->success_url,
            "notify_url" => $this->success_url,
            "webhook_url" => $this->webhook_url,
            "client_info" => array(
                "full_name" => $fullname,
            ),
            "bill" => array(
                "bill_id" => $order_id,
                "sum" => $amount,
                "currency" => "KZT",
                "claims" => array(
                    array(
                      "claim_id" => $order_id,
                      "sum" => $amount,
                      "payment_type_id" => $this->payment_type_id,
                    )
                )
            )
          );
    
        $ctp_url = $this->address . '/api/banks/call_payment_page';
    
        $curl = curl_init($ctp_url);
        curl_setopt($curl, CURLOPT_HEADER, 0);
        curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, 0);
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($curl, CURLOPT_HTTPHEADER, array(
            'Content-Type: application/json',
            'Authorization: Bearer ' . $this->token
        ));
        curl_setopt($curl, CURLOPT_FORBID_REUSE, 1);
        curl_setopt($curl, CURLOPT_FRESH_CONNECT, 1);
        curl_setopt($curl, CURLOPT_POST, 1);
        curl_setopt($curl, CURLOPT_POSTFIELDS, json_encode( $body, true ));
    
        $response = curl_exec($curl);
        $curl_error = curl_error($curl);
        $curl_errno = curl_errno($curl);
        curl_close($curl);
    
        if (!$response) {
            return "";
        }
    
        $data = json_decode($response,true);
    
        if (!isset($data["url"])) {
            return "";
        }
    
        return $data["url"];
    }
}
